from tendenci.apps.perms.managers import TendenciBaseManager

class ContributionManager(TendenciBaseManager):
    """
    Model Manager
    """
    pass
